summaryrefslogtreecommitdiff
path: root/src/plugins/geoservices/osm/qgeoroutereplyosm.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/plugins/geoservices/osm/qgeoroutereplyosm.cpp')
-rw-r--r--src/plugins/geoservices/osm/qgeoroutereplyosm.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/plugins/geoservices/osm/qgeoroutereplyosm.cpp b/src/plugins/geoservices/osm/qgeoroutereplyosm.cpp
index bca345fe..f704a714 100644
--- a/src/plugins/geoservices/osm/qgeoroutereplyosm.cpp
+++ b/src/plugins/geoservices/osm/qgeoroutereplyosm.cpp
@@ -344,10 +344,10 @@ void QGeoRouteReplyOsm::networkReplyFinished()
int status = object.value(QStringLiteral("status")).toDouble();
QString statusMessage = object.value(QStringLiteral("status_message")).toString();
// status code is 0 in case of success
// status code is 207 if no route was found
// an error occurred when trying to find a route
- if (0 != status) {
+ if (0 != status && 200 != status) {
setError(QGeoRouteReply::UnknownError, statusMessage);
m_reply->deleteLater();
m_reply = 0;
@@ -344,10 +344,10 @@ void QGeoRouteReplyOsm::networkReplyFinished()
int status = object.value(QStringLiteral("status")).toDouble();
QString statusMessage = object.value(QStringLiteral("status_message")).toString();
- // status code is 0 in case of success
+ // status code 0 or 200 are case of success
// status code is 207 if no route was found
// an error occurred when trying to find a route